"use strict";
this.name = "bigShips_populator";
this.author = "Thargoid & Eric Walch";
this.copyright = "Creative Commons Attribution - Non-Commercial - Share Alike 3.0 license.";
this.description = "Populator for generic big ships facilitator OXP.";
this.version = "1.3";

this._maxBigTraders = 2;
this._debug = true;
/*
	The main reason for using this generic populator instead of a custom one is to avoid overpopulation of a system. 
	When every oxp with bigTraders would use its own addition script, it would mean that if you have 10 of such oxp's 
	installed, you would also see 10 times as much of those ships in the system. With this generic populator you just 
	get more variation when adding more oxp's with such big traders.

	For programmers only:
	To check in JS if the populator is loaded, use if(worldScripts["bigShips_populator"]) , which will be true if it 
	is present. This way your script knows if the player has installed the oxp. If not, you can act upon it. e.g. by 
	giving a warning or do the population by yourself. 
*/

// configuration settings for use in Lib_Config
this._bigShipsConfig = {Name:this.name, Alias:"Big Ships Populator", Display:"Config", Alive:"_bigShipsConfig",
	Bool: {
		B0: {Name:"_debug", Def:false, Desc: "Debug messages"},
		Info:"0 - Turn debug messages on/off"},
    SInt: {
        S0:{Name:"_maxBigTraders", Def:2, Min:0, Max:5, Desc:"Max big traders"},
        Info:"0 - Maximum number of big trader ships to spawn"},
};

//-------------------------------------------------------------------------------------------------------------
this.startUp = function() {
	// register our settings, if Lib_Config is present
    if (worldScripts.Lib_Config) worldScripts.Lib_Config._registerSet(this._bigShipsConfig);
	if (missionVariables.BigShips_MaxTraders) this._maxBigTrader = parseInt(missionVariables.BigShips_MaxTraders);
}

//-------------------------------------------------------------------------------------------------------------
this.playerWillSaveGame = function() {
	missionVariables.BigShips_MaxTraders = this._maxBigTraders;
}

//-------------------------------------------------------------------------------------------------------------
this.systemWillPopulate = function () {
	if (!system.isInterstellarSpace && !system.sun.isGoingNova && !system.sun.hasGoneNova) {
		var productivity = system.productivity;
		var radius = system.mainPlanet.radius;
		var bigTraderCount = 0
		for (var loopCount = 0; loopCount < 5; loopCount++) {
			// 56320 is maximum possible value of productivity.
			if (productivity > ((Math.random() * 56320) + (bigTraderCount * 5000)) && radius > Math.random() * 70E3) {
				//system.legacy_addShipsWithinRadius("bigTrader", 1, "pwu", [0, 0, (Math.random() * 0.7) + 0.2], radius*0.5);
				system.setPopulator("bigTrader-" + loopCount, {
					location: "COORDINATES",
					coordinates: Vector3D(0, 0, (Math.random() * 0.7) + 0.2).fromCoordinateSystem("pwu"),
					callback: function (pos) {
						var bt = system.addShips("bigTrader", 1, pos, radius * 0.5);
					}
				});
				++bigTraderCount
				if (bigTraderCount >= this._maxBigTraders) break;
			}
		}
		if(this._debug) log(this.name, bigTraderCount + " big trader(s) added to the " + system.name + " system.");
	}
}